.. -*- mode: rst; fill-column: 78; indent-tabs-mode: nil -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###
  #
  #   See COPYING file distributed along with the PyMVPA package for the
  #   copyright and license terms.
  #
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###


.. index:: Support
.. _chap_support:

********************
Where To Get Support
********************

If you have problems installing the software or questions about usage,
documentation or something else related to PyMVPA, you can post to the PyMVPA
mailing list (preferred) or contact the authors on IRC:

:Mailing list: pkg-exppsy-pymvpa@lists.alioth.debian.org [subscription_,
               archive_]
:IRC: #neurodebian on OFTC

All users should subscribe to the mailing list. PyMVPA is still a young project
that is under heavy development. Significant modifications (hopefully
improvements) are very likely to happen frequently. The mailing list is the
preferred way to announce such changes. The mailing list archive can also be
searched using the *mailing list archive search* located in the sidebar of the
PyMVPA home page.

.. _subscription: http://lists.alioth.debian.org/mailman/listinfo/pkg-exppsy-pymvpa
.. _archive: http://lists.alioth.debian.org/pipermail/pkg-exppsy-pymvpa/


Reporting A Bug
---------------

If you think you have discovered a bug, please report it.  Only known bugs can
be fixed.  If you have a GitHub_ account, the easiest way to report a bug is
via the `issue tracker`_ -- just click the "Create Issue" button, describe
your problem, and submit.  If your are using a Debian package of PyMVPA, you
can alternatively use the :command:`reportbug` command.  We would appreciate
if in your bug report you would include the output of call to
:func:`mvpa2.wtf()<mvpa2.base.info.wtf>`, which summarizes the details of your
system.

If you spot an error in the documentation, simply leave a comment at the
bottom of the corresponding webpage on *pympva.org* (comments can be made
without the need for any type of account).

If you don't like either way, please post to the user mailing list (see above).

.. _GitHub: http://github.com
.. _issue tracker: http://github.com/PyMVPA/PyMVPA/issues


